@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: main.c 7020 2008-11-02 20:16:08Z charles $
+ * $Id: main.c 7463 2008-12-22 05:39:02Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -652,8 +652,7 @@ appsetup( TrWindow *      wind,
 
     /* start scheduled rate timer */
     updateScheduledLimits ( tr_core_session( cbdata->core ) );
-    g_timeout_add( 60 * 1000, updateScheduledLimits,
-                  tr_core_session( cbdata->core ) );
+    gtr_timeout_add_seconds( 60, updateScheduledLimits, tr_core_session( cbdata->core ) );
 
     /* either show the window or iconify it */
     if( !minimized )
@@ -1116,6 +1115,14 @@ prefschanged( TrCore * core UNUSED,
         g_message( "setting encryption to %d", encryption );
         tr_sessionSetEncryption( tr, encryption );
     }
+    else if( !strcmp( key, PREF_KEY_BLOCKLIST_ENABLED ) )
+    {
+        tr_blocklistSetEnabled( tr, pref_flag_get( key ) ); 
+    }
+    else if( !strcmp( key, PREF_KEY_DOWNLOAD_DIR ) )
+    {
+        tr_sessionSetDownloadDir( tr, pref_string_get( key ) );
+    }
     else if( !strcmp( key, PREF_KEY_PORT ) )
     {
         const int port = pref_int_get( key );
@@ -1158,13 +1165,11 @@ prefschanged( TrCore * core UNUSED,
     }
     else if( !strcmp( key, PREF_KEY_PORT_FORWARDING ) )
     {
-        const gboolean enabled = pref_flag_get( key );
-        tr_sessionSetPortForwardingEnabled( tr, enabled );
+        tr_sessionSetPortForwardingEnabled( tr, pref_flag_get( key ) );
     }
     else if( !strcmp( key, PREF_KEY_PEX ) )
     {
-        const gboolean b = pref_flag_get( key );
-        tr_sessionSetPortForwardingEnabled( tr, b );
+        tr_sessionSetPexEnabled( tr, pref_flag_get( key ) );
     }
     else if( !strcmp( key, PREF_KEY_RPC_ENABLED ) )
     {
@@ -1232,6 +1237,10 @@ prefschanged( TrCore * core UNUSED,
         const char * s = pref_string_get( key );
         tr_sessionSetProxyPassword( tr, s );
     }
+    else if( !strcmp( key, PREF_KEY_PORT ) )
+    {
+        tr_sessionSetProxyPort( tr, pref_int_get( key ) );
+    }
 }
 
 static gboolean
