@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: tr-prefs.c 7041 2008-11-04 20:53:37Z charles $
+ * $Id: tr-prefs.c 7478 2008-12-23 20:42:27Z charles $
  */
 
 #include <ctype.h> /* isspace */
@@ -1117,7 +1117,8 @@ new_time_combo( GObject *    core,
         struct tm   tm;
         tm.tm_hour = i / 60;
         tm.tm_min = i % 60;
-        strftime( buf, sizeof( buf ), "%I:%M %p", &tm );
+        tm.tm_sec = 0;
+        strftime( buf, sizeof( buf ), "%H:%M", &tm );
         gtk_list_store_append( store, &iter );
         gtk_list_store_set( store, &iter, 0, i, 1, buf, -1 );
     }
@@ -1310,7 +1311,7 @@ onCorePrefsChanged( TrCore * core UNUSED,
         data = g_new0( struct test_port_data, 1 );
         data->label = ndata->label;
         data->alive = ndata->alive;
-        g_timeout_add( 3000, testing_port_begin, data );
+        gtr_timeout_add_seconds( 3, testing_port_begin, data );
     }
 }
 
