@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: util.c 6873 2008-10-09 20:03:34Z charles $
+ * $Id: util.c 7463 2008-12-22 05:39:02Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -641,3 +641,18 @@ gtr_button_new_from_stock( const char * stock,
     return button;
 }
 
+/***
+****
+***/
+
+guint
+gtr_timeout_add_seconds( guint        interval,
+                         GSourceFunc  function,
+                         gpointer     data )
+{
+#if GLIB_CHECK_VERSION( 2,14,0 )
+    return g_timeout_add_seconds( interval, function, data );
+#else
+    return g_timeout_add( interval*1000, function, data );
+#endif
+}
