@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: blocklist.c 6897 2008-10-14 03:39:16Z charles $
+ * $Id: blocklist.c 7254 2008-12-03 05:34:28Z charles $
  */
 
 #include <stdio.h>
@@ -198,7 +198,7 @@ _tr_blocklistSetEnabled( tr_blocklist * b,
 }
 
 int
-_tr_blocklistHasAddress( tr_blocklist *         b,
+_tr_blocklistHasAddress( tr_blocklist         * b,
                          const struct in_addr * addr )
 {
     uint32_t                   needle;
@@ -257,9 +257,10 @@ _tr_blocklistSetContent( tr_blocklist * b,
 
     while( !fggets( &line, in ) )
     {
-        char *             rangeBegin;
-        char *             rangeEnd;
-        struct in_addr     in_addr;
+        char *  rangeBegin;
+        char *  rangeEnd;
+        char *  crpos;
+        struct in_addr in_addr;
         struct tr_ip_range range;
 
         rangeBegin = strrchr( line, ':' );
@@ -270,6 +271,9 @@ _tr_blocklistSetContent( tr_blocklist * b,
         if( !rangeEnd ){ free( line ); continue; }
         *rangeEnd++ = '\0';
 
+        if(( crpos = strchr( rangeEnd, '\r' )))
+            *crpos = '\0';
+
         if( tr_netResolve( rangeBegin, &in_addr ) )
             tr_err( "blocklist skipped invalid address [%s]\n", rangeBegin );
         range.begin = ntohl( in_addr.s_addr );
