@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: completion.h 6935 2008-10-20 17:54:56Z charles $
+ * $Id: completion.h 7175 2008-11-29 16:32:10Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -25,6 +25,10 @@
 #ifndef TR_COMPLETION_H
 #define TR_COMPLETION_H
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #include "transmission.h"
 
 struct tr_bitfield;
