@@ -7,12 +7,16 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: crypto.h 6947 2008-10-22 17:19:22Z charles $
+ * $Id: crypto.h 7175 2008-11-29 16:32:10Z charles $
  */
 
 #ifndef TR_ENCRYPTION_H
 #define TR_ENCRYPTION_H
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #include <inttypes.h>
 
 #include "utils.h" /* TR_GNUC_NULL_TERMINATED */
