@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: inout.h 6842 2008-10-03 04:49:06Z charles $
+ * $Id: inout.h 7175 2008-11-29 16:32:10Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -22,6 +22,10 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #ifndef TR_IO_H
 #define TR_IO_H 1
 
