@@ -7,9 +7,13 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: list.h 6795 2008-09-23 19:11:04Z charles $
+ * $Id: list.h 7470 2008-12-22 19:20:46Z charles $
  */
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #ifndef TR_LIST_H
 #define TR_LIST_H
 
@@ -44,19 +48,9 @@ void*    tr_list_remove( tr_list **        list,
                          const void *      b,
                          TrListCompareFunc compare_func );
 
-void     tr_list_insert_sorted( tr_list **        list,
-                                void *            data,
-                                TrListCompareFunc compare_func );
-
 tr_list* tr_list_find( tr_list *         list,
                        const void *      b,
                        TrListCompareFunc compare_func );
 
-tr_list* tr_list_find_data( tr_list *    list,
-                            const void * data );
-
-void     tr_list_foreach( tr_list *         list,
-                          TrListForeachFunc foreach_func );
-
 #endif /* TR_LIST_H */
 
