@@ -3,11 +3,11 @@
  *
  * This file is licensed by the GPL version 2.  Works owned by the
  * Transmission project are granted a special exemption to clause 2(b)
- * so that the bulk of its code can remain under the MIT license. 
+ * so that the bulk of its code can remain under the MIT license.
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: natpmp.c 6181 2008-06-13 21:08:16Z charles $
+ * $Id: natpmp.c 7009 2008-11-01 16:39:57Z charles $
  */
 
 #include <assert.h>
@@ -15,23 +15,20 @@
 #include <time.h>
 #include <inttypes.h>
 
-#ifdef WIN32
-#include <winsock2.h> /* inet_ntoa */
-#else
-#include <arpa/inet.h> /* inet_ntoa */
-#endif
-
+#define ENABLE_STRNATPMPERR
 #include <libnatpmp/natpmp.h>
 
 #include "transmission.h"
 #include "natpmp.h"
+#include "net.h" /* inet_ntoa() */
 #include "port-forwarding.h"
 #include "utils.h"
 
 #define LIFETIME_SECS 3600
 #define COMMAND_WAIT_SECS 8
 
-static const char * getKey( void ) { return _( "Port Forwarding (NAT-PMP)" ); }
+static const char *
+getKey( void ) { return _( "Port Forwarding (NAT-PMP)" ); }
 
 typedef enum
 {
@@ -45,16 +42,16 @@ typedef enum
     TR_NATPMP_RECV_UNMAP
 }
 tr_natpmp_state;
-    
+
 struct tr_natpmp
 {
-    int port;
-    unsigned int isMapped      : 1;
-    unsigned int hasDiscovered : 1;
-    time_t renewTime;
-    time_t commandTime;
-    tr_natpmp_state state;
-    natpmp_t natpmp;
+    int                port;
+    unsigned int       isMapped      : 1;
+    unsigned int       hasDiscovered : 1;
+    time_t             renewTime;
+    time_t             commandTime;
+    tr_natpmp_state    state;
+    natpmp_t           natpmp;
 };
 
 /**
@@ -62,20 +59,25 @@ struct tr_natpmp
 **/
 
 static void
-logVal( const char * func, int ret )
+logVal( const char * func,
+        int          ret )
 {
     if( ret == NATPMP_TRYAGAIN )
         return;
     if( ret >= 0 )
-        tr_ninf( getKey(), _( "%s succeeded (%d)" ), func, ret );
+        tr_ninf( getKey( ), _( "%s succeeded (%d)" ), func, ret );
     else
-        tr_ndbg( getKey(), "%s failed (%d): %s (%d)", func, ret, tr_strerror(errno), errno );
+        tr_ndbg(
+             getKey( ),
+            "%s failed.  natpmp returned %d (%s); errno is %d (%s)",
+            func, ret, strnatpmperr( ret ), errno, tr_strerror( errno ) );
 }
 
 struct tr_natpmp*
 tr_natpmpInit( void )
 {
     struct tr_natpmp * nat;
+
     nat = tr_new0( struct tr_natpmp, 1 );
     nat->state = TR_NATPMP_DISCOVER;
     nat->port = -1;
@@ -95,17 +97,19 @@ tr_natpmpClose( tr_natpmp * nat )
 static int
 canSendCommand( const struct tr_natpmp * nat )
 {
-    return time(NULL) >= nat->commandTime;
+    return time( NULL ) >= nat->commandTime;
 }
 
 static void
 setCommandTime( struct tr_natpmp * nat )
 {
-    nat->commandTime = time(NULL) + COMMAND_WAIT_SECS;
+    nat->commandTime = time( NULL ) + COMMAND_WAIT_SECS;
 }
 
 int
-tr_natpmpPulse( struct tr_natpmp * nat, int port, int isEnabled )
+tr_natpmpPulse( struct tr_natpmp * nat,
+                int                port,
+                int                isEnabled )
 {
     int ret;
 
@@ -123,12 +127,18 @@ tr_natpmpPulse( struct tr_natpmp * nat, int port, int isEnabled )
     if( ( nat->state == TR_NATPMP_RECV_PUB ) && canSendCommand( nat ) )
     {
         natpmpresp_t response;
-        const int val = readnatpmpresponseorretry( &nat->natpmp, &response );
+        const int    val = readnatpmpresponseorretry( &nat->natpmp,
+                                                      &response );
         logVal( "readnatpmpresponseorretry", val );
-        if( val >= 0 ) {
-            tr_ninf( getKey(), _( "Found public address \"%s\"" ), inet_ntoa( response.pnu.publicaddress.addr ) );
+        if( val >= 0 )
+        {
+            tr_ninf( getKey( ), _(
+                        "Found public address \"%s\"" ),
+                    inet_ntoa( response.pnu.publicaddress.addr ) );
             nat->state = TR_NATPMP_IDLE;
-        } else if( val != NATPMP_TRYAGAIN ) {
+        }
+        else if( val != NATPMP_TRYAGAIN )
+        {
             nat->state = TR_NATPMP_ERR;
         }
     }
@@ -141,7 +151,10 @@ tr_natpmpPulse( struct tr_natpmp * nat, int port, int isEnabled )
 
     if( ( nat->state == TR_NATPMP_SEND_UNMAP ) && canSendCommand( nat ) )
     {
-        const int val = sendnewportmappingrequest( &nat->natpmp, NATPMP_PROTOCOL_TCP, nat->port, nat->port, 0 );
+        const int val =
+            sendnewportmappingrequest( &nat->natpmp, NATPMP_PROTOCOL_TCP,
+                                       nat->port, nat->port,
+                                       0 );
         logVal( "sendnewportmappingrequest", val );
         nat->state = val < 0 ? TR_NATPMP_ERR : TR_NATPMP_RECV_UNMAP;
         setCommandTime( nat );
@@ -150,14 +163,21 @@ tr_natpmpPulse( struct tr_natpmp * nat, int port, int isEnabled )
     if( nat->state == TR_NATPMP_RECV_UNMAP )
     {
         natpmpresp_t resp;
-        const int val = readnatpmpresponseorretry( &nat->natpmp, &resp );
+        const int    val = readnatpmpresponseorretry( &nat->natpmp, &resp );
         logVal( "readnatpmpresponseorretry", val );
-        if( val >= 0 ) {
-            tr_ninf( getKey(), _( "no longer forwarding port %d" ), nat->port );
-            nat->state = TR_NATPMP_IDLE;
-            nat->port = -1;
-            nat->isMapped = 0;
-        } else if( val != NATPMP_TRYAGAIN ) {
+        if( val >= 0 )
+        {
+            const int port = resp.pnu.newportmapping.privateport;
+            tr_ninf( getKey( ), _( "no longer forwarding port %d" ), port );
+            if( nat->port == port )
+            {
+                nat->port = -1;
+                nat->state = TR_NATPMP_IDLE;
+                nat->isMapped = 0;
+            }
+        }
+        else if( val != NATPMP_TRYAGAIN )
+        {
             nat->state = TR_NATPMP_ERR;
         }
     }
@@ -167,13 +187,17 @@ tr_natpmpPulse( struct tr_natpmp * nat, int port, int isEnabled )
         if( isEnabled && !nat->isMapped && nat->hasDiscovered )
             nat->state = TR_NATPMP_SEND_MAP;
 
-        else if( nat->isMapped && time(NULL) >= nat->renewTime )
+        else if( nat->isMapped && time( NULL ) >= nat->renewTime )
             nat->state = TR_NATPMP_SEND_MAP;
     }
 
     if( ( nat->state == TR_NATPMP_SEND_MAP ) && canSendCommand( nat ) )
     {
-        const int val = sendnewportmappingrequest( &nat->natpmp, NATPMP_PROTOCOL_TCP, port, port, LIFETIME_SECS );
+        const int val =
+            sendnewportmappingrequest( &nat->natpmp, NATPMP_PROTOCOL_TCP,
+                                       port,
+                                       port,
+                                       LIFETIME_SECS );
         logVal( "sendnewportmappingrequest", val );
         nat->state = val < 0 ? TR_NATPMP_ERR : TR_NATPMP_RECV_MAP;
         setCommandTime( nat );
@@ -182,28 +206,43 @@ tr_natpmpPulse( struct tr_natpmp * nat, int port, int isEnabled )
     if( nat->state == TR_NATPMP_RECV_MAP )
     {
         natpmpresp_t resp;
-        const int val = readnatpmpresponseorretry( &nat->natpmp, &resp );
+        const int    val = readnatpmpresponseorretry( &nat->natpmp, &resp );
         logVal( "readnatpmpresponseorretry", val );
-        if( val >= 0 ) {
+        if( val >= 0 )
+        {
             nat->state = TR_NATPMP_IDLE;
             nat->isMapped = 1;
             nat->renewTime = time( NULL ) + LIFETIME_SECS;
             nat->port = resp.pnu.newportmapping.privateport;
-            tr_ninf( getKey(), _( "Port %d forwarded successfully" ), nat->port );
-        } else if( val != NATPMP_TRYAGAIN ) {
+            tr_ninf( getKey( ), _(
+                         "Port %d forwarded successfully" ), nat->port );
+        }
+        else if( val != NATPMP_TRYAGAIN )
+        {
             nat->state = TR_NATPMP_ERR;
         }
     }
 
-    switch( nat->state ) {
-        case TR_NATPMP_IDLE:        ret = nat->isMapped ? TR_NAT_TRAVERSAL_MAPPED : TR_NAT_TRAVERSAL_UNMAPPED; break;
-        case TR_NATPMP_DISCOVER:    ret = TR_NAT_TRAVERSAL_UNMAPPED; break;
+    switch( nat->state )
+    {
+        case TR_NATPMP_IDLE:
+            ret = nat->isMapped ? TR_PORT_MAPPED : TR_PORT_UNMAPPED; break;
+
+        case TR_NATPMP_DISCOVER:
+            ret = TR_PORT_UNMAPPED; break;
+
         case TR_NATPMP_RECV_PUB:
         case TR_NATPMP_SEND_MAP:
-        case TR_NATPMP_RECV_MAP:    ret = TR_NAT_TRAVERSAL_MAPPING; break;
+        case TR_NATPMP_RECV_MAP:
+            ret = TR_PORT_MAPPING; break;
+
         case TR_NATPMP_SEND_UNMAP:
-        case TR_NATPMP_RECV_UNMAP:  ret = TR_NAT_TRAVERSAL_UNMAPPING; break;
-        default:                    ret = TR_NAT_TRAVERSAL_ERROR; break;
+        case TR_NATPMP_RECV_UNMAP:
+            ret = TR_PORT_UNMAPPING; break;
+
+        default:
+            ret = TR_PORT_ERROR; break;
     }
     return ret;
 }
+
