@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: net.c 5290 2008-03-18 19:14:21Z charles $
+ * $Id: net.c 7455 2008-12-22 00:51:14Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -30,11 +30,11 @@
 #include <sys/types.h>
 
 #ifdef WIN32
-#include <winsock2.h> /* inet_addr */
+ #include <winsock2.h> /* inet_addr */
 #else
-#include <arpa/inet.h> /* inet_addr */
-#include <netdb.h>
-#include <fcntl.h>
+ #include <arpa/inet.h> /* inet_addr */
+ #include <netdb.h>
+ #include <fcntl.h>
 #endif
 
 #include <evutil.h>
@@ -43,6 +43,7 @@
 #include "fdlimit.h"
 #include "natpmp.h"
 #include "net.h"
+#include "peer-io.h"
 #include "platform.h"
 #include "utils.h"
 
@@ -51,49 +52,69 @@ void
 tr_netInit( void )
 {
     static int initialized = FALSE;
+
     if( !initialized )
     {
 #ifdef WIN32
         WSADATA wsaData;
-        WSAStartup(MAKEWORD(2,2), &wsaData);
+        WSAStartup( MAKEWORD( 2, 2 ), &wsaData );
 #endif
         initialized = TRUE;
     }
 }
 
-/***********************************************************************
- * DNS resolution
- * 
- * Synchronous "resolution": only works with character strings
- * representing numbers expressed in the Internet standard `.' notation.
- * Returns a non-zero value if an error occurs.
- **********************************************************************/
-int tr_netResolve( const char * address, struct in_addr * addr )
+tr_bool
+tr_isAddress( const tr_address * a )
 {
-    addr->s_addr = inet_addr( address );
-    return ( addr->s_addr == 0xFFFFFFFF );
+    return a != NULL; /* this is implemented better in 1.50 */
 }
 
 
 /***********************************************************************
- * TCP/UDP sockets
+ * DNS resolution
+ *
+ * Synchronous "resolution": only works with character strings
+ * representing numbers expressed in the Internet standard `.' notation.
+ * Returns a non-zero value if an error occurs.
  **********************************************************************/
+int
+tr_netResolve( const char *     address,
+               struct in_addr * addr )
+{
+    addr->s_addr = inet_addr( address );
+    return addr->s_addr == 0xFFFFFFFF;
+}
+
+/***********************************************************************
+ * TCP sockets
+ **********************************************************************/
+
+int
+tr_netSetTOS( int s,
+              int tos )
+{
+#ifdef IP_TOS
+    return setsockopt( s, IPPROTO_IP, IP_TOS, (char*)&tos, sizeof( tos ) );
+#else
+    return 0;
+#endif
+}
 
 static int
 makeSocketNonBlocking( int fd )
 {
     if( fd >= 0 )
     {
-#if defined(__BEOS__)
+#if defined( __BEOS__ )
         int flags = 1;
         if( setsockopt( fd, SOL_SOCKET, SO_NONBLOCK,
-                        &flags, sizeof( int ) ) < 0 )
+                       &flags, sizeof( int ) ) < 0 )
 #else
         if( evutil_make_socket_nonblocking( fd ) )
 #endif
         {
             tr_err( _( "Couldn't create socket: %s" ),
-                    tr_strerror( sockerrno ) );
+                   tr_strerror( sockerrno ) );
             tr_netClose( fd );
             fd = -1;
         }
@@ -103,22 +124,38 @@ makeSocketNonBlocking( int fd )
 }
 
 static int
-createSocket( int type, int priority )
+createSocket( int type )
 {
-    return makeSocketNonBlocking( tr_fdSocketCreate( type, priority ) );
+    return makeSocketNonBlocking( tr_fdSocketCreate( type ) );
 }
 
-static int
-tr_netOpen( const struct in_addr * addr, tr_port_t port,
-            int type, int priority )
+static void
+setSndBuf( tr_session * session UNUSED, int fd UNUSED )
 {
-    int s;
-    struct sockaddr_in sock;
-
-    if( ( s = createSocket( type, priority ) ) < 0 )
+#if 0
+    if( fd >= 0 )
     {
-        return -1;
+        const int sndbuf = session->so_sndbuf;
+        const int rcvbuf = session->so_rcvbuf;
+        setsockopt( fd, SOL_SOCKET, SO_SNDBUF, &sndbuf, sizeof( sndbuf ) );
+        setsockopt( fd, SOL_SOCKET, SO_RCVBUF, &rcvbuf, sizeof( rcvbuf ) );
     }
+#endif
+}
+
+int
+tr_netOpenTCP( tr_session            * session,
+               const struct in_addr  * addr,
+               tr_port_t               port )
+{
+    int                s;
+    struct sockaddr_in sock;
+    const int          type = SOCK_STREAM;
+
+    if( ( s = createSocket( type ) ) < 0 )
+        return -1;
+
+    setSndBuf( session, s );
 
     memset( &sock, 0, sizeof( sock ) );
     sock.sin_family      = AF_INET;
@@ -126,38 +163,38 @@ tr_netOpen( const struct in_addr * addr, tr_port_t port,
     sock.sin_port        = port;
 
     if( ( connect( s, (struct sockaddr *) &sock,
-                   sizeof( struct sockaddr_in ) ) < 0 )
+                  sizeof( struct sockaddr_in ) ) < 0 )
 #ifdef WIN32
-        && ( sockerrno != WSAEWOULDBLOCK )
+      && ( sockerrno != WSAEWOULDBLOCK )
 #endif
-        && ( sockerrno != EINPROGRESS ) )
+      && ( sockerrno != EINPROGRESS ) )
     {
-        tr_err( _( "Couldn't connect socket %d to %s, port %d (errno %d - %s)" ),
-                s, inet_ntoa(*addr), port,
-                sockerrno, tr_strerror(sockerrno) );
+        tr_err( _(
+                   "Couldn't connect socket %d to %s, port %d (errno %d - %s)" ),
+               s, inet_ntoa( *addr ), port,
+               sockerrno, tr_strerror( sockerrno ) );
         tr_netClose( s );
         s = -1;
     }
 
+    tr_deepLog( __FILE__, __LINE__, NULL, "New OUTGOING connection %d (%s)",
+               s, tr_peerIoAddrStr( addr, port ) );
+
     return s;
 }
-  
-int
-tr_netOpenTCP( const struct in_addr * addr, tr_port_t port, int priority )
-{
-    return tr_netOpen( addr, port, SOCK_STREAM, priority );
-}
 
-static int
-tr_netBind( int port, int type )
+int
+tr_netBindTCP( int port )
 {
-    int s;
+    int                s;
     struct sockaddr_in sock;
+    const int          type = SOCK_STREAM;
+
 #if defined( SO_REUSEADDR ) || defined( SO_REUSEPORT )
-    int optval;
+    int                optval;
 #endif
 
-    if( ( s = createSocket( type, 1 ) ) < 0 )
+    if( ( s = createSocket( type ) ) < 0 )
         return -1;
 
 #ifdef SO_REUSEADDR
@@ -171,66 +208,27 @@ tr_netBind( int port, int type )
     sock.sin_port        = htons( port );
 
     if( bind( s, (struct sockaddr *) &sock,
-               sizeof( struct sockaddr_in ) ) )
+             sizeof( struct sockaddr_in ) ) )
     {
-        tr_err( _( "Couldn't bind port %d: %s" ), port, tr_strerror(sockerrno) );
+        tr_err( _( "Couldn't bind port %d: %s" ), port,
+               tr_strerror( sockerrno ) );
         tr_netClose( s );
         return -1;
     }
-     
-    tr_inf( _( "Bound socket %d to port %d" ), s, port );
+
+    tr_dbg(  "Bound socket %d to port %d", s, port );
     return s;
 }
 
 int
-tr_netBindTCP( int port )
+tr_netAccept( tr_session      * session,
+              int               b,
+              struct in_addr  * addr,
+              tr_port_t       * port )
 {
-    return tr_netBind( port, SOCK_STREAM );
-}
-
-int
-tr_netAccept( int b, struct in_addr * addr, tr_port_t * port )
-{
-    return makeSocketNonBlocking( tr_fdSocketAccept( b, addr, port ) );
-}
-
-int
-tr_netSend( int s, const void * buf, int size )
-{
-    const int ret = send( s, buf, size, 0 );
-    if( ret >= 0 )
-        return ret;
-
-    if( sockerrno == ENOTCONN || sockerrno == EAGAIN || sockerrno == EWOULDBLOCK )
-        return TR_NET_BLOCK;
-
-    return TR_NET_CLOSE;
-}
-
-int tr_netRecvFrom( int s, uint8_t * buf, int size, struct sockaddr_in * addr )
-{
-    socklen_t len;
-    int       ret;
-
-    len = ( NULL == addr ? 0 : sizeof( *addr ) );
-    ret = recvfrom( s, buf, size, 0, ( struct sockaddr * ) addr, &len );
-    if( ret < 0 )
-    {
-        if( sockerrno == EAGAIN || sockerrno == EWOULDBLOCK )
-        {
-            ret = TR_NET_BLOCK;
-        }
-        else
-        {
-            ret = TR_NET_CLOSE;
-        }
-    }
-    if( !ret )
-    {
-        ret = TR_NET_CLOSE;
-    }
-
-    return ret;
+    int fd = makeSocketNonBlocking( tr_fdSocketAccept( b, addr, port ) );
+    setSndBuf( session, fd );
+    return fd;
 }
 
 void
@@ -240,11 +238,22 @@ tr_netClose( int s )
 }
 
 void
-tr_netNtop( const struct in_addr * addr, char * buf, int len )
+tr_netNtop( const struct in_addr * addr,
+            char *                 buf,
+            int                    len )
 {
     const uint8_t * cast;
 
     cast = (const uint8_t *)addr;
-    snprintf( buf, len, "%hhu.%hhu.%hhu.%hhu",
-              cast[0], cast[1], cast[2], cast[3] );
+    tr_snprintf( buf, len, "%hhu.%hhu.%hhu.%hhu",
+                 cast[0], cast[1], cast[2], cast[3] );
+}
+
+int
+tr_compareAddresses( const struct in_addr * a, const struct in_addr * b )
+{
+    if( a->s_addr != b->s_addr )
+        return a->s_addr < b->s_addr ? -1 : 1;
+
+    return 0;
 }
