@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: net.h 5501 2008-04-04 01:21:37Z charles $
+ * $Id: net.h 7455 2008-12-22 00:51:14Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -22,70 +22,85 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #ifndef _TR_NET_H_
 #define _TR_NET_H_
 
 #ifdef WIN32
-    #include <inttypes.h>
-    #include <winsock2.h>
-    typedef int socklen_t;
-    typedef uint16_t tr_port_t;
-#elif defined(__BEOS__)
-    #include <sys/socket.h>
-    #include <netinet/in.h>
-    typedef unsigned short tr_port_t;
-    typedef int socklen_t;
+ #include <inttypes.h>
+ #include <winsock2.h>
+ typedef int socklen_t;
+ typedef uint16_t tr_port_t;
+#elif defined( __BEOS__ )
+ #include <sys/socket.h>
+ #include <netinet/in.h>
+ typedef unsigned short tr_port_t;
+ typedef int socklen_t;
 #else
-    #include <sys/types.h>
-    #include <sys/socket.h>
-    #include <netinet/in.h>
-    #include <arpa/inet.h>
-    typedef in_port_t tr_port_t;
+ #include <sys/types.h>
+ #include <sys/socket.h>
+ #include <netinet/in.h>
+ #include <arpa/inet.h>
+ typedef in_port_t tr_port_t;
 #endif
 
 #ifdef WIN32
-    #define ECONNREFUSED WSAECONNREFUSED
-    #define ECONNRESET   WSAECONNRESET
-    #define EHOSTUNREACH WSAEHOSTUNREACH
-    #define EINPROGRESS  WSAEINPROGRESS
-    #define ENOTCONN     WSAENOTCONN
-    #define EWOULDBLOCK  WSAEWOULDBLOCK
-    #define sockerrno WSAGetLastError( )
+ #define ECONNREFUSED WSAECONNREFUSED
+ #define ECONNRESET   WSAECONNRESET
+ #define EHOSTUNREACH WSAEHOSTUNREACH
+ #define EINPROGRESS  WSAEINPROGRESS
+ #define ENOTCONN     WSAENOTCONN
+ #define EWOULDBLOCK  WSAEWOULDBLOCK
+ #define sockerrno WSAGetLastError( )
 #else
-    #include <errno.h>
-    #define sockerrno errno
+ #include <errno.h>
+ #define sockerrno errno
 #endif
 
 struct in_addr;
 struct sockaddr_in;
+struct tr_session;
+
+typedef struct in_addr tr_address;
+
+tr_bool tr_isAddress( const tr_address * a );
 
 /***********************************************************************
  * DNS resolution
  **********************************************************************/
-int tr_netResolve( const char *, struct in_addr * );
+int  tr_netResolve( const  char *,
+                    struct in_addr * );
 
 
 /***********************************************************************
- * TCP and UDP sockets
+ * Sockets
  **********************************************************************/
-int  tr_netOpenTCP  ( const struct in_addr * addr, tr_port_t port, int priority );
-int  tr_netOpenUDP  ( const struct in_addr * addr, tr_port_t port, int priority );
-int  tr_netBindTCP  ( int port );
-int  tr_netBindUDP  ( int port );
-int  tr_netAccept   ( int s, struct in_addr *, tr_port_t * );
-void tr_netClose    ( int s );
+int  tr_netOpenTCP( struct tr_handle     * session,
+                    const struct in_addr * addr,
+                    tr_port_t              port );
 
-#define TR_NET_BLOCK 0x80000000
-#define TR_NET_CLOSE 0x40000000
-int  tr_netSend    ( int s, const void * buf, int size );
-#define tr_netRecv( s, buf, size ) tr_netRecvFrom( (s), (buf), (size), NULL )
-int  tr_netRecvFrom( int s, uint8_t * buf, int size, struct sockaddr_in * );
+int  tr_netBindTCP( int port );
 
-void tr_netNtop( const struct in_addr * addr, char * buf, int len );
+int  tr_netAccept( struct tr_handle  * session,
+                   int                 bound,
+                   struct in_addr    * setme_addr,
+                   tr_port_t         * setme_port );
 
-void tr_netInit ( void );
+int  tr_netSetTOS( int s,
+                   int tos );
 
+void tr_netClose( int s );
 
-#define tr_addrcmp( aa, bb )    memcmp( ( void * )(aa), ( void * )(bb), 4)
+void tr_netNtop( const struct in_addr * addr,
+                 char *                 buf,
+                 int                    len );
+
+int tr_compareAddresses( const struct in_addr * a,
+                         const struct in_addr * b );
+
+void tr_netInit( void );
 
 #endif /* _TR_NET_H_ */
