@@ -7,9 +7,13 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: peer-common.h 6876 2008-10-10 00:38:37Z charles $
+ * $Id: peer-common.h 7455 2008-12-22 00:51:14Z charles $
  */
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #ifndef TR_PEER_H
 #define TR_PEER_H
 
@@ -18,7 +22,6 @@
 **/
 
 #include "transmission.h"
-#include "publish.h"
 
 typedef enum
 {
@@ -38,10 +41,13 @@ typedef enum
 {
     TR_PEER_CLIENT_GOT_BLOCK,
     TR_PEER_CLIENT_GOT_DATA,
+    TR_PEER_CLIENT_GOT_ALLOWED_FAST,
+    TR_PEER_CLIENT_GOT_SUGGEST,
     TR_PEER_PEER_GOT_DATA,
     TR_PEER_PEER_PROGRESS,
     TR_PEER_ERROR,
     TR_PEER_CANCEL,
+    TR_PEER_UPLOAD_ONLY,
     TR_PEER_NEED_REQ
 }
 PeerEventType;
@@ -49,11 +55,13 @@ PeerEventType;
 typedef struct
 {
     PeerEventType    eventType;
-    uint32_t         pieceIndex; /* for GOT_BLOCK, CANCEL */
-    uint32_t         offset; /* for GOT_BLOCK */
-    uint32_t         length; /* for GOT_BLOCK + GOT_DATA */
-    float            progress; /* for TR_PEER_PEER_PROGRESS */
-    int              err; /* errno for TR_PEER_GOT_ERROR */
+    uint32_t         pieceIndex;   /* for GOT_BLOCK, CANCEL, ALLOWED, SUGGEST */
+    uint32_t         offset;       /* for GOT_BLOCK */
+    uint32_t         length;       /* for GOT_BLOCK + GOT_DATA */
+    float            progress;     /* for PEER_PROGRESS */
+    int              err;          /* errno for GOT_ERROR */
+    tr_bool          wasPieceData; /* for GOT_DATA */
+    tr_bool          uploadOnly;   /* for UPLOAD_ONLY */
 }
 tr_peer_event;
 
