@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: platform.c 7019 2008-11-02 15:58:30Z charles $
+ * $Id: platform.c 7406 2008-12-16 00:57:25Z charles $
  */
 
 #ifdef __BEOS__
@@ -582,18 +582,24 @@ tr_getClutchDir( const tr_session * session UNUSED )
             }
 
             /* XDG_DATA_DIRS are the backup directories */
-            tmp = getenv( "XDG_DATA_DIRS" );
-            if( !tmp || !*tmp )
-                tmp =  PACKAGE_DATA_DIR ":/usr/local/share/:/usr/share/";
-            while( tmp && *tmp ) {
-                const char * end = strchr( tmp, ':' );
-                if( end ) {
-                    tr_list_append( &candidates, tr_strndup( tmp, end - tmp ) );
-                    tmp = end + 1;
-                } else {
-                    tr_list_append( &candidates, tr_strdup( tmp ) );
-                    break;
+            {
+                const char * pkg = PACKAGE_DATA_DIR;
+                const char * xdg = getenv( "XDG_DATA_DIRS" );
+                const char * fallback = "/usr/local/share:/usr/share";
+                char * buf = tr_strdup_printf( "%s:%s:%s", (pkg?pkg:""), (xdg?xdg:""), fallback );
+                tmp = buf;
+                while( tmp && *tmp ) {
+                    const char * end = strchr( tmp, ':' );
+                    if( end ) {
+                        if( ( end - tmp ) > 1 )
+                            tr_list_append( &candidates, tr_strndup( tmp, end - tmp ) );
+                        tmp = end + 1;
+                    } else if( tmp && *tmp ) {
+                        tr_list_append( &candidates, tr_strdup( tmp ) );
+                        break;
+                    }
                 }
+                tr_free( buf );
             }
 
             /* walk through the candidates & look for a match */
