@@ -7,7 +7,7 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: session.c 7069 2008-11-08 02:49:04Z charles $
+ * $Id: session.c 7365 2008-12-13 22:52:13Z charles $
  */
 
 #include <assert.h>
@@ -21,6 +21,7 @@
 #include <dirent.h> /* opendir */
 
 #include "transmission.h"
+#include "bandwidth.h"
 #include "blocklist.h"
 #include "fdlimit.h"
 #include "list.h"
@@ -29,7 +30,6 @@
 #include "peer-mgr.h"
 #include "platform.h" /* tr_lock */
 #include "port-forwarding.h"
-#include "ratecontrol.h"
 #include "rpc-server.h"
 #include "stats.h"
 #include "torrent.h"
@@ -254,10 +254,8 @@ tr_sessionInitFull( const char *       configDir,
     h->isProxyAuthEnabled = proxyAuthIsEnabled != 0;
     h->proxyUsername = tr_strdup( proxyUsername );
     h->proxyPassword = tr_strdup( proxyPassword );
-    h->pieceSpeed[TR_PEER_TO_CLIENT] = tr_rcInit( );
-    h->pieceSpeed[TR_CLIENT_TO_PEER] = tr_rcInit( );
-    h->rawSpeed[TR_PEER_TO_CLIENT] = tr_rcInit( );
-    h->rawSpeed[TR_CLIENT_TO_PEER] = tr_rcInit( );
+    h->so_sndbuf = 1500 * 3; /* 3x MTU for most ethernet/wireless */
+    h->so_rcvbuf = 8192;
 
     if( configDir == NULL )
         configDir = tr_getDefaultConfigDir( );
@@ -276,15 +274,16 @@ tr_sessionInitFull( const char *       configDir,
 
     /* Initialize rate and file descripts controls */
 
-    h->uploadLimit = uploadLimit;
-    h->useUploadLimit = useUploadLimit;
-    h->downloadLimit = downloadLimit;
-    h->useDownloadLimit = useDownloadLimit;
-
     tr_fdInit( globalPeerLimit );
     h->shared = tr_sharedInit( h, isPortForwardingEnabled, publicPort );
     h->isPortSet = publicPort >= 0;
 
+    h->bandwidth = tr_bandwidthNew( h, NULL );
+    tr_sessionSetSpeedLimit       ( h, TR_UP,   uploadLimit );
+    tr_sessionSetSpeedLimitEnabled( h, TR_UP,   useUploadLimit );
+    tr_sessionSetSpeedLimit       ( h, TR_DOWN, downloadLimit );
+    tr_sessionSetSpeedLimitEnabled( h, TR_DOWN, useDownloadLimit );
+
     /* first %s is the application name
        second %s is the version number */
     tr_inf( _( "%s %s started" ), TR_NAME, LONG_VERSION_STRING );
@@ -442,43 +441,58 @@ tr_sessionGetPortForwarding( const tr_handle * h )
 ****
 ***/
 
-void
-tr_sessionSetSpeedLimitEnabled( tr_handle *  h,
-                                tr_direction direction,
-                                int          use_flag )
+static void
+updateBandwidth( tr_session * session, tr_direction dir )
 {
-    assert( h );
-    assert( direction == TR_UP || direction == TR_DOWN );
+    const tr_bool zeroCase = session->speedLimit[dir] < 1 && session->isSpeedLimited[dir];
 
-    if( direction == TR_UP )
-        h->useUploadLimit = use_flag ? 1 : 0;
-    else
-        h->useDownloadLimit = use_flag ? 1 : 0;
-}
+    tr_bandwidthSetLimited( session->bandwidth, dir, session->isSpeedLimited[dir] && !zeroCase );
 
-int
-tr_sessionIsSpeedLimitEnabled( const tr_handle * h,
-                               tr_direction      direction )
-{
-    return direction == TR_UP ? h->useUploadLimit : h->useDownloadLimit;
+    tr_bandwidthSetDesiredSpeed( session->bandwidth, dir, session->speedLimit[dir] );
 }
 
 void
-tr_sessionSetSpeedLimit( tr_handle *  h,
-                         tr_direction direction,
-                         int          KiB_sec )
+tr_sessionSetSpeedLimitEnabled( tr_session      * session,
+                                tr_direction      dir,
+                                tr_bool           isLimited )
 {
-    if( direction == TR_DOWN )
-        h->downloadLimit = KiB_sec;
-    else
-        h->uploadLimit = KiB_sec;
+    assert( session );
+    assert( dir==TR_UP || dir==TR_DOWN );
+
+    session->isSpeedLimited[dir] = isLimited;
+    updateBandwidth( session, dir );
+}
+
+void
+tr_sessionSetSpeedLimit( tr_session    * session,
+                         tr_direction    dir,
+                         int             desiredSpeed )
+{
+    assert( session );
+    assert( dir==TR_UP || dir==TR_DOWN );
+
+    session->speedLimit[dir] = desiredSpeed;
+    updateBandwidth( session, dir );
+}
+
+tr_bool
+tr_sessionIsSpeedLimitEnabled( const tr_session  * session,
+                               tr_direction        dir )
+{
+    assert( session );
+    assert( dir==TR_UP || dir==TR_DOWN );
+
+    return session->isSpeedLimited[dir];
 }
 
 int
-tr_sessionGetSpeedLimit( const tr_handle * h,
-                         tr_direction      direction )
+tr_sessionGetSpeedLimit( const tr_session  * session,
+                         tr_direction        dir )
 {
-    return direction == TR_UP ? h->uploadLimit : h->downloadLimit;
+    assert( session );
+    assert( dir==TR_UP || dir==TR_DOWN );
+
+    return session->speedLimit[dir];
 }
 
 /***
@@ -505,17 +519,13 @@ tr_sessionGetPeerLimit( const tr_handle * handle UNUSED )
 double
 tr_sessionGetPieceSpeed( const tr_session * session, tr_direction dir )
 {
-    assert( dir==TR_UP || dir==TR_DOWN );
-
-    return session ? tr_rcRate( session->pieceSpeed[dir] ) : 0.0;
+    return session ? tr_bandwidthGetPieceSpeed( session->bandwidth, dir ) : 0.0;
 }
 
 double
 tr_sessionGetRawSpeed( const tr_session * session, tr_direction dir )
 {
-    assert( dir==TR_UP || dir==TR_DOWN );
-
-    return session ? tr_rcRate( session->rawSpeed[dir] ) : 0.0;
+    return session ? tr_bandwidthGetPieceSpeed( session->bandwidth, dir ) : 0.0;
 }
 
 int
@@ -629,10 +639,7 @@ tr_sessionClose( tr_handle * session )
     }
 
     /* free the session memory */
-    tr_rcClose( session->pieceSpeed[TR_PEER_TO_CLIENT] );
-    tr_rcClose( session->pieceSpeed[TR_CLIENT_TO_PEER] );
-    tr_rcClose( session->rawSpeed[TR_PEER_TO_CLIENT] );
-    tr_rcClose( session->rawSpeed[TR_CLIENT_TO_PEER] );
+    tr_bandwidthFree( session->bandwidth );
     tr_lockFree( session->lock );
     for( i = 0; i < session->metainfoLookupCount; ++i )
         tr_free( session->metainfoLookup[i].filename );
