@@ -7,9 +7,13 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: stats.h 7039 2008-11-04 17:37:51Z charles $
+ * $Id: stats.h 7175 2008-11-29 16:32:10Z charles $
  */
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #ifndef TR_STATS_H
 #define TR_STATS_H
 
