@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: torrent.h 7069 2008-11-08 02:49:04Z charles $
+ * $Id: torrent.h 7365 2008-12-13 22:52:13Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -22,9 +22,14 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #ifndef TR_TORRENT_H
 #define TR_TORRENT_H 1
 
+struct tr_bandwidth;
 struct tr_ratecontrol;
 
 /**
@@ -81,7 +86,7 @@ tr_torrent* tr_torrentFindFromObfuscatedHash( tr_session    * session,
 
 int         tr_torrentAllowsPex( const tr_torrent * );
 
-int         tr_torrentIsPieceTransferAllowed( const tr_torrent * torrent,
+tr_bool     tr_torrentIsPieceTransferAllowed( const tr_torrent * torrent,
                                               tr_direction       direction );
 
 /* get the index of this piece's first block */
@@ -167,10 +172,7 @@ struct tr_torrent
     tr_session *             session;
     tr_info                  info;
 
-    int                      uploadLimit;
-    tr_speedlimit            uploadLimitMode;
-    int                      downloadLimit;
-    tr_speedlimit            downloadLimitMode;
+    tr_speedlimit            speedLimitMode[2];
 
     struct tr_ratecontrol *  swarmSpeed;
 
@@ -179,8 +181,17 @@ struct tr_torrent
 
     uint8_t                  obfuscatedHash[SHA_DIGEST_LENGTH];
 
+    /* If the initiator of the connection receives a handshake in which the
+     * peer_id does not match the expected peerid, then the initiator is
+     * expected to drop the connection. Note that the initiator presumably
+     * received the peer information from the tracker, which includes the
+     * peer_id that was registered by the peer. The peer_id from the tracker
+     * and in the handshake are expected to match.
+     */
+    uint8_t * peer_id;
+
     /* Where to download */
-    char *  downloadDir;
+    char * downloadDir;
 
     /* How many bytes we ask for per request */
     uint32_t                   blockSize;
@@ -215,8 +226,8 @@ struct tr_torrent
     tr_torrent_completeness_func *   completeness_func;
     void *                     completeness_func_user_data;
 
-    unsigned int               isRunning  : 1;
-    unsigned int               isDeleting : 1;
+    tr_bool                    isRunning;
+    tr_bool                    isDeleting;
 
     uint16_t                   maxConnectedPeers;
 
@@ -229,12 +240,7 @@ struct tr_torrent
 
     int                        uniqueId;
 
-    /* the rate at which pieces are being transferred between client and
-     * its peers.  protocol overhead is NOT included; only the piece data */
-    struct tr_ratecontrol    * pieceSpeed[2];
-
-    /* the rate at which bytes are being sent between client and peers */
-    struct tr_ratecontrol    * rawSpeed[2];
+    struct tr_bandwidth      * bandwidth;
 };
 
 #endif
