@@ -7,9 +7,13 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: tracker.h 6795 2008-09-23 19:11:04Z charles $
+ * $Id: tracker.h 7175 2008-11-29 16:32:10Z charles $
  */
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #ifndef _TR_TRACKER_H_
 #define _TR_TRACKER_H_
 
