@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: transmission.h 7069 2008-11-08 02:49:04Z charles $
+ * $Id: transmission.h 7455 2008-12-22 00:51:14Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -52,20 +52,19 @@ extern "C" {
 typedef uint32_t tr_file_index_t;
 typedef uint32_t tr_piece_index_t;
 typedef uint64_t tr_block_index_t;
+typedef uint16_t tr_port;
+typedef uint8_t tr_bool;
+
 
 /**
  * @brief returns Transmission's default configuration file directory.
  *
  * The default configuration directory is determined this way:
- * - If the TRANSMISSION_HOME environmental variable is set,
- *   its value is returned.
- * - otherwise, if we're running on Darwin,
- *   "$HOME/Library/Application Support/Transmission" is returned.
- * - otherwise, if we're running on WIN32,
- *   "$EXE_FOLDER/Transmission" is returned.
- * - otherwise, if XDG_CONFIG_HOME is set,
- *   "$XDG_CONFIG_HOME/transmission" is returned.
- * - lastly, $HOME/.config/transmission" is used.
+ * 1. If the TRANSMISSION_HOME environmental variable is set, its value is used.
+ * 2. On Darwin, "${HOME}/Library/Application Support/Transmission" is used.
+ * 3. On Windows, "${CSIDL_APPDATA}/Transmission" is used.
+ * 4. If XDG_CONFIG_HOME is set, "${XDG_CONFIG_HOME}/transmission" is used.
+ * 5. ${HOME}/.config/transmission" is used as a last resort.
  */
 const char* tr_getDefaultConfigDir( void );
 
@@ -555,25 +554,26 @@ typedef enum
 }
 tr_direction;
 
-void       tr_sessionSetSpeedLimitEnabled( tr_session    * session,
-                                           tr_direction    direction,
-                                           int             isEnabled );
+void       tr_sessionSetSpeedLimitEnabled ( tr_session        * session,
+                                            tr_direction        direction,
+                                            tr_bool             isEnabled );
 
-double     tr_sessionGetRawSpeed( const tr_session  * session,
-                                  tr_direction        direection );
+tr_bool    tr_sessionIsSpeedLimitEnabled  ( const tr_session  * session,
+                                            tr_direction        direction );
 
-double     tr_sessionGetPieceSpeed( const tr_session  * session,
-                                    tr_direction        direection );
+void       tr_sessionSetSpeedLimit        ( tr_session        * session,
+                                            tr_direction        direction,
+                                            int                 KiB_sec );
 
-int        tr_sessionIsSpeedLimitEnabled( const tr_session  * session,
-                                          tr_direction       direction );
+int        tr_sessionGetSpeedLimit        ( const tr_session  * session,
+                                            tr_direction        direction );
 
-void       tr_sessionSetSpeedLimit( tr_session     * session,
-                                    tr_direction     direction,
-                                    int              KiB_sec );
+double     tr_sessionGetRawSpeed          ( const tr_session  * session,
+                                           tr_direction         direction );
+
+double     tr_sessionGetPieceSpeed        ( const tr_session  * session,
+                                            tr_direction        direction );
 
-int        tr_sessionGetSpeedLimit( const tr_session  * session,
-                                    tr_direction        direction );
 
 void       tr_sessionSetPeerLimit( tr_session  * session,
                                    uint16_t      maxGlobalPeers );
@@ -1032,26 +1032,27 @@ int  tr_torrentCanManualUpdate( const tr_torrent * torrent );
 
 typedef struct tr_peer_stat
 {
-    unsigned int    isEncrypted        : 1;
-    unsigned int    isDownloadingFrom  : 1;
-    unsigned int    isUploadingTo      : 1;
+    tr_bool      isEncrypted;
+    tr_bool      isDownloadingFrom;
+    tr_bool      isUploadingTo;
+    tr_bool      isSeed;
 
-    unsigned int    peerIsChoked       : 1;
-    unsigned int    peerIsInterested   : 1;
-    unsigned int    clientIsChoked     : 1;
-    unsigned int    clientIsInterested : 1;
-    unsigned int    isIncoming         : 1;
+    tr_bool      peerIsChoked;
+    tr_bool      peerIsInterested;
+    tr_bool      clientIsChoked;
+    tr_bool      clientIsInterested;
+    tr_bool      isIncoming;
 
-    uint8_t         from;
-    uint16_t        port;
+    uint8_t      from;
+    tr_port      port;
 
-    char            addr[16];
-    char            client[80];
-    char            flagStr[32];
+    char         addr[16];
+    char         client[80];
+    char         flagStr[32];
 
-    float           progress;
-    float           rateToPeer;
-    float           rateToClient;
+    float        progress;
+    float        rateToPeer;
+    float        rateToClient;
 }
 tr_peer_stat;
 
@@ -1427,6 +1428,9 @@ void tr_torrentSetActivityDate( tr_torrent * torrent,
 void tr_torrentSetDoneDate( tr_torrent  * torrent,
                             time_t        doneDate );
 
+/** @brief Sanity checker to test that the direction is TR_UP or TR_DOWN */
+tr_bool tr_isDirection( tr_direction );
+
 /** @} */
 
 #ifdef __TRANSMISSION__
