@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: utils.c 6993 2008-10-30 19:47:00Z charles $
+ * $Id: utils.c 7455 2008-12-22 00:51:14Z charles $
  *
  * Copyright (c) 2005-2008 Transmission authors and contributors
  *
@@ -1272,3 +1272,8 @@ tr_base64_decode( const void * input,
     return ret;
 }
 
+tr_bool
+tr_isDirection( tr_direction dir )
+{
+    return dir==TR_UP || dir==TR_DOWN;
+}
