@@ -7,15 +7,20 @@
  * This exemption does not extend to derived works not owned by
  * the Transmission project.
  *
- * $Id: webseed.h 6882 2008-10-11 04:07:50Z charles $
+ * $Id: webseed.h 7455 2008-12-22 00:51:14Z charles $
  */
 
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
+
 #ifndef TR_WEBSEED_H
 #define TR_WEBSEED_H
 
 typedef struct tr_webseed tr_webseed;
 
 #include "peer-common.h"
+#include "publish.h"
 
 tr_webseed* tr_webseedNew( struct tr_torrent * torrent,
                            const char *        url,
