@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: BadgeView.m 4740 2008-01-19 05:37:16Z livings124 $
+ * $Id: BadgeView.m 7077 2008-11-08 22:13:00Z livings124 $
  *
  * Copyright (c) 2007-2008 Transmission authors and contributors
  *
@@ -25,11 +25,11 @@
 #import "BadgeView.h"
 #import "NSStringAdditions.h"
 
-#define BETWEEN_PADDING 2.0
+#define BETWEEN_PADDING 2.0f
 
 @interface BadgeView (Private)
 
-- (void) badge: (NSImage *) badge string: (NSString *) string atHeight: (float) height;
+- (void) badge: (NSImage *) badge string: (NSString *) string atHeight: (CGFloat) height adjustForQuit: (BOOL) quit;
 
 @end
 
@@ -40,51 +40,61 @@
     if ((self = [super initWithFrame: frame]))
     {
         fLib = lib;
+        
+        fDownloadRate = 0.0;
+        fUploadRate = 0.0;
         fQuitting = NO;
     }
     return self;
 }
 
-- (void) setQuitting
-{
-    fQuitting = YES;
-}
-
 - (void) dealloc
 {
     [fAttributes release];
     [super dealloc];
 }
 
+- (BOOL) setRatesWithDownload: (CGFloat) downloadRate upload: (CGFloat) uploadRate
+{
+    //only needs update if the badges were displayed or are displayed now
+    if (fDownloadRate == downloadRate && fUploadRate == uploadRate)
+        return NO;
+    
+    fDownloadRate = downloadRate;
+    fUploadRate = uploadRate;
+    return YES;
+}
+
+- (void) setQuitting
+{
+    fQuitting = YES;
+}
+
 - (void) drawRect: (NSRect) rect
 {
     [[NSImage imageNamed: @"NSApplicationIcon"] drawInRect: rect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0];
     
     if (fQuitting)
     {
-        [self badge: [NSImage imageNamed: @"QuitBadge.png"] string: NSLocalizedString(@"Quitting", "Dock Badger -> quit")
-                atHeight:  (rect.size.height - [[NSImage imageNamed: @"QuitBadge.png"] size].height) * 0.5];
+        NSImage * quitBadge = [NSImage imageNamed: @"QuitBadge.png"];
+        [self badge: quitBadge string: NSLocalizedString(@"Quitting", "Dock Badger -> quit")
+                atHeight: (rect.size.height - [quitBadge size].height) * 0.5f adjustForQuit: YES];
         return;
     }
     
-    BOOL checkDownload = [[NSUserDefaults standardUserDefaults] boolForKey: @"BadgeDownloadRate"],
-        checkUpload = [[NSUserDefaults standardUserDefaults] boolForKey: @"BadgeUploadRate"];
-    if (checkDownload || checkUpload)
+    BOOL upload = fUploadRate >= 0.1f,
+        download = fDownloadRate >= 0.1f;
+    CGFloat bottom = 0.0f;
+    if (upload)
     {
-        float downloadRate, uploadRate;
-        tr_torrentRates(fLib, &downloadRate, &uploadRate);
-        
-        BOOL upload = checkUpload && uploadRate >= 0.1;
-        if (upload)
-            [self badge: [NSImage imageNamed: @"UploadBadge.png"] string: [NSString stringForSpeedAbbrev: uploadRate] atHeight: 0.0];
-        if (checkDownload && downloadRate >= 0.1)
-        {
-            //download rate above upload rate
-            float bottom = upload ? [[NSImage imageNamed: @"UploadBadge.png"] size].height + BETWEEN_PADDING : 0.0;
-            [self badge: [NSImage imageNamed: @"DownloadBadge.png"] string: [NSString stringForSpeedAbbrev: downloadRate]
-                    atHeight: bottom];
-        }
+        NSImage * uploadBadge = [NSImage imageNamed: @"UploadBadge.png"];
+        [self badge: uploadBadge string: [NSString stringForSpeedAbbrev: fUploadRate] atHeight: bottom adjustForQuit: NO];
+        if (download)
+            bottom += [uploadBadge size].height + BETWEEN_PADDING; //download rate above upload rate
     }
+    if (download)
+        [self badge: [NSImage imageNamed: @"DownloadBadge.png"] string: [NSString stringForSpeedAbbrev: fDownloadRate]
+                atHeight: bottom adjustForQuit: NO];
 }
 
 @end
@@ -92,17 +102,17 @@
 @implementation BadgeView (Private)
 
 //dock icon must have locked focus
-- (void) badge: (NSImage *) badge string: (NSString *) string atHeight: (float) height
+- (void) badge: (NSImage *) badge string: (NSString *) string atHeight: (CGFloat) height adjustForQuit: (BOOL) quit
 {
     if (!fAttributes)
     {
         NSShadow * stringShadow = [[NSShadow alloc] init];
-        [stringShadow setShadowOffset: NSMakeSize(2.0, -2.0)];
-        [stringShadow setShadowBlurRadius: 4.0];
+        [stringShadow setShadowOffset: NSMakeSize(2.0f, -2.0f)];
+        [stringShadow setShadowBlurRadius: 4.0f];
         
         fAttributes = [[NSDictionary alloc] initWithObjectsAndKeys:
             [NSColor whiteColor], NSForegroundColorAttributeName,
-            [NSFont boldSystemFontOfSize: 26.0], NSFontAttributeName, stringShadow, NSShadowAttributeName, nil];
+            [NSFont boldSystemFontOfSize: 26.0f], NSFontAttributeName, stringShadow, NSShadowAttributeName, nil];
         
         [stringShadow release];
     }
@@ -111,14 +121,14 @@
     badgeRect.size = [badge size];
     badgeRect.origin.y = height;
     
-    [badge drawInRect: badgeRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0];
+    [badge drawInRect: badgeRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0f];
     
     //string is in center of image
     NSSize stringSize = [string sizeWithAttributes: fAttributes];
     
     NSRect stringRect = badgeRect;
-    stringRect.origin.x += (badgeRect.size.width - stringSize.width) * 0.5;
-    stringRect.origin.y += (badgeRect.size.height - stringSize.height) * 0.5 + 1.0; //adjust for shadow
+    stringRect.origin.x += (badgeRect.size.width - stringSize.width) * 0.5f;
+    stringRect.origin.y += (badgeRect.size.height - stringSize.height) * 0.5f + (quit ? 2.0f : 1.0f); //adjust for shadow, extra for quit
     stringRect.size = stringSize;
     
     [string drawInRect: stringRect withAttributes: fAttributes];
