@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: DragOverlayWindow.m 5351 2008-03-24 02:58:16Z livings124 $
+ * $Id: DragOverlayWindow.m 7013 2008-11-01 22:08:02Z livings124 $
  *
  * Copyright (c) 2007-2008 Transmission authors and contributors
  *
@@ -25,18 +25,19 @@
 #import "DragOverlayWindow.h"
 #import "DragOverlayView.h"
 #import "NSStringAdditions.h"
+#import "metainfo.h"
 
 @implementation DragOverlayWindow
 
 - (id) initWithLib: (tr_handle *) lib forWindow: (NSWindow *) window
 {
-    if (self = ([super initWithContentRect: NSMakeRect(0, 0, 1.0, 1.0) styleMask: NSBorderlessWindowMask
-                    backing: NSBackingStoreBuffered defer: NO]))
+    if ((self = ([super initWithContentRect: NSMakeRect(0, 0, 1.0, 1.0) styleMask: NSBorderlessWindowMask
+                    backing: NSBackingStoreBuffered defer: NO])))
     {
         fLib = lib;
         
-        [self setBackgroundColor: [NSColor colorWithCalibratedWhite: 0.0 alpha: 0.5]];
-        [self setAlphaValue: 0.0];
+        [self setBackgroundColor: [NSColor colorWithCalibratedWhite: 0.0f alpha: 0.5f]];
+        [self setAlphaValue: 0.0f];
         [self setOpaque: NO];
         [self setHasShadow: NO];
         
@@ -75,22 +76,21 @@
 - (void) setTorrents: (NSArray *) files
 {
     uint64_t size = 0;
-    int count = 0;
+    NSInteger count = 0;
     
     NSString * name;
     BOOL folder;
-    int fileCount = 0;
+    NSInteger fileCount = 0;
     
     NSString * file;
     NSEnumerator * enumerator = [files objectEnumerator];
-    tr_ctor * ctor;
-    tr_info info;
     while ((file = [enumerator nextObject]))
     {
         if ([[file pathExtension] caseInsensitiveCompare: @"torrent"] == NSOrderedSame)
         {
-            ctor = tr_ctorNew(fLib);
+            tr_ctor * ctor = tr_ctorNew(fLib);
             tr_ctorSetMetainfoFromFile(ctor, [file UTF8String]);
+            tr_info info;
             if (tr_torrentParse(fLib, ctor, &info) == TR_OK)
             {
                 count++;
@@ -118,9 +118,9 @@
     {
         NSString * fileString;
         if (fileCount == 1)
-            fileString = NSLocalizedString(@"1 File", "Drag overlay -> torrents");
+            fileString = NSLocalizedString(@"1 file", "Drag overlay -> torrents");
         else
-            fileString= [NSString stringWithFormat: NSLocalizedString(@"%d Files", "Drag overlay -> torrents"), fileCount];
+            fileString= [NSString stringWithFormat: NSLocalizedString(@"%d files", "Drag overlay -> torrents"), fileCount];
         secondString = [NSString stringWithFormat: @"%@, %@", fileString, secondString];
     }
     
@@ -130,7 +130,7 @@
     else
     {
         name = [NSString stringWithFormat: NSLocalizedString(@"%d Torrent Files", "Drag overlay -> torrents"), count];
-        secondString = [secondString stringByAppendingString: @" Total"];
+        secondString = [secondString stringByAppendingString: @" total"];
         icon = [NSImage imageNamed: @"TransmissionDocument.icns"];
     }
     
@@ -172,7 +172,7 @@
         [fFadeInAnimation stopAnimation];
         [fFadeOutAnimation setCurrentProgress: 1.0 - [fFadeInAnimation currentProgress]];
     }
-    if ([self alphaValue] > 0.0)
+    if ([self alphaValue] > 0.0f)
         [fFadeOutAnimation startAnimation];
 }
 
