@@ -1,19 +1,30 @@
 #! /bin/sh
 #
-# $Id: version.sh 7096 2008-11-10 15:30:42Z charles $
+# $Id: version.sh 7492 2008-12-24 17:41:10Z livings124 $
 
 # convention: -TR MAJOR MINOR MAINT STATUS - (each a single char)
 # STATUS: "X" for prerelease test builds,
 #         "Z" for unsupported trunk builds,
 #         "0" for stable, supported releases
 # these should be the only two lines you need to change
-PEERID_PREFIX="-TR1400-"
-USERAGENT_PREFIX="1.40"
+PEERID_PREFIX="-TR1420-"
+USERAGENT_PREFIX="1.42"
 
-SVN_REVISION=`find ./macosx ./libtransmission -name "*\.[chmp]" -o -name "*\.cpp" -o -name "*\.po" -o -name "*\.sh" | \
+SVN_REVISION=`find ./libtransmission -name "*\.[chmp]" -o -name "*\.cpp" -o -name "*\.po" -o -name "*\.sh" | \
               xargs grep "\$Id:" | \
               grep -v third-party | \
               cut -d"$Id:" -f3 | cut -d" " -f3 | sort -n | tail -n 1`
+
+#dirty fix to ensure the highest version number is found when running release_builder.sh
+SVN_REVISION_MAC=`find ./macosx -name "*\.[chmp]" -o -name "*\.cpp" -o -name "*\.po" -o -name "*\.sh" | \
+              xargs grep "\$Id:" | \
+              grep -v third-party | \
+              cut -d"$Id:" -f3 | cut -d" " -f3 | sort -n | tail -n 1`
+
+if [ $SVN_REVISION_MAC -gt $SVN_REVISION ]
+then
+	SVN_REVISION=$SVN_REVISION_MAC
+fi
   
 # Generate files to be included: only overwrite them if changed so make
 # won't rebuild everything unless necessary
